@@ -113,6 +113,13 @@ sub offset {
     return $self->{offset}[$dir];
 }
 
+# give requests a chance to cleanup before destroying connection
+sub DESTROY {
+    my $self = shift;
+    @{$self->{requests}} = ();
+}
+
+
 # process request data
 sub _in0 {
     my ($self,$data,$eof,$time) = @_;
@@ -527,8 +534,8 @@ sub _in1 {
 	    $self->xdebug("read until eof");
 	    $self->{offset}[1] += length($data);
 	    $bytes += length($data);
-	    $data = '';
 	    $obj->in_response_body($data,$eof,$time) if $obj;
+	    $data = '';
 	    pop(@$rqs) if $eof; # request done
 	    return $bytes;
 
@@ -637,6 +644,12 @@ sub new_request {
     return $self->{upper_flow}->new_request(@_,$self)
 }
 
+# return number of open requests
+sub open_requests {
+    my $self = shift;
+    return 0 + @{$self->{requests}};
+}
+
 sub fatal {
     my ($self,$reason,$dir,$time) = @_;
     $self->xtrace($reason);
@@ -815,6 +828,10 @@ dumps the state of the open connections via xdebug
 returns the current offset in the data stream, that is the position
 behind the within the in_* methods forwarded data.
 
+=item $connection->open_requests
+
+returns the number of open requests, if any.
+
 =back
 
 =head1 LIMITS
